pecos.decoders.mwpm2d.precomputing
==================================

.. automodule:: pecos.decoders.mwpm2d.precomputing







   .. rubric:: Functions

   .. autosummary::

      code_surface4444
      code_surface4444medial
      compute_all_shortest_paths
      precompute
      surface4444_identity
      surface4444medial_identity
